==> elasticloadbalancingv2-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/IApplicationLoadBalancer.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * An application load balancer.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:23:50.803Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IApplicationLoadBalancer extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.elasticloadbalancingv2.ILoadBalancerV2, software.amazon.awscdk.services.ec2.IConnectable {
    /**
     * The ARN of this load balancer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getLoadBalancerArn();
    /**
     * The VPC this load balancer has been created in (if available).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.ec2.IVpc getVpc();
    /**
     * Add a new listener to this load balancer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener addListener(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.BaseApplicationListenerProps props);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancer {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The ARN of this load balancer.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getLoadBalancerArn() {
            return this.jsiiGet("loadBalancerArn", java.lang.String.class);
        }

        /**
         * The VPC this load balancer has been created in (if available).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.jsiiGet("vpc", software.amazon.awscdk.services.ec2.IVpc.class);
        }

        /**
         * The canonical hosted zone ID of this load balancer.
         * 
         * Example:
         * 
         * Z2P70J7EXAMPLE
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getLoadBalancerCanonicalHostedZoneId() {
            return this.jsiiGet("loadBalancerCanonicalHostedZoneId", java.lang.String.class);
        }

        /**
         * The DNS name of this load balancer.
         * 
         * Example:
         * 
         * my-load-balancer-424835706.us-west-2.elb.amazonaws.com
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getLoadBalancerDnsName() {
            return this.jsiiGet("loadBalancerDnsName", java.lang.String.class);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }

        /**
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.ec2.Connections getConnections() {
            return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
        }

        /**
         * Add a new listener to this load balancer.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener addListener(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.BaseApplicationListenerProps props) {
            return this.jsiiCall("addListener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
        }
    }
}

==> elasticloadbalancingv2-1.5.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/IApplicationLoadBalancer.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * An application load balancer.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-21T10:55:00.809Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IApplicationLoadBalancer extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.elasticloadbalancingv2.ILoadBalancerV2, software.amazon.awscdk.services.ec2.IConnectable {
    /**
     * The ARN of this load balancer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getLoadBalancerArn();

    /**
     * The VPC this load balancer has been created in (if available).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.ec2.IVpc getVpc();

    /**
     * Add a new listener to this load balancer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener addListener(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.BaseApplicationListenerProps props);


    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancer {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * The ARN of this load balancer.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getLoadBalancerArn() {
            return this.jsiiGet("loadBalancerArn", java.lang.String.class);
        }

        /**
         * The VPC this load balancer has been created in (if available).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.jsiiGet("vpc", software.amazon.awscdk.services.ec2.IVpc.class);
        }

        /**
         * The canonical hosted zone ID of this load balancer.
         * 
         * Example:
         * 
         * Z2P70J7EXAMPLE
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getLoadBalancerCanonicalHostedZoneId() {
            return this.jsiiGet("loadBalancerCanonicalHostedZoneId", java.lang.String.class);
        }

        /**
         * The DNS name of this load balancer.
         * 
         * Example:
         * 
         * my-load-balancer-424835706.us-west-2.elb.amazonaws.com
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getLoadBalancerDnsName() {
            return this.jsiiGet("loadBalancerDnsName", java.lang.String.class);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }

        /**
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.ec2.Connections getConnections() {
            return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
        }

        /**
         * Add a new listener to this load balancer.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener addListener(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.BaseApplicationListenerProps props) {
            return this.jsiiCall("addListener", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
        }
    }
}
